NowPlayingMetadata class

Constructors

NowPlayingMetadata({required String title, String? subtitle, String? artworkUrl, bool isLive = false, Duration? duration})
const

Properties

artworkUrl String?
final
duration Duration?
final
hashCode int
The hash code for this object.
no setterinherited
isLive bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited