VideoControlsController class

Internal controller used by the SDK to coordinate default video controls.

Constructors

VideoControlsController()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

hideControls() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register({required VoidCallback restartVisibilityTimer, required VoidCallback showControls, required VoidCallback hideControls, required ValueChanged<bool> setControlsPinned}) Object
restartVisibilityTimer() → void
setControlsPinned(bool pinned) → void
showControls() → void
toString() String
A string representation of this object.
inherited
unregister(Object token) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited