VideoQualityOption class

Constructors

VideoQualityOption({required String id, required String label, required String url, int? width, int? height, int? bandwidth, bool isAutoDiscovered = false})
const

Properties

bandwidth int?
final
hashCode int
The hash code for this object.
no setterinherited
height int?
final
id String
final
isAutoDiscovered bool
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final
width int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited