CustomVideoControls class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CustomVideoControls
Constructors
-
CustomVideoControls({Key? key, required Player player, required dynamic onControlsVisibilityChanged(bool visbility), bool syncVisibilityWithParent = true, required VideoControlsController controlsController, required VideoControlsConfig videoControlsConfig, required List<
VideoQualityOption> availableQualities, required VideoQualityOption? currentQuality, required Future<void> onQualitySelected(VideoQualityOption quality)?, required ZerorateHlsPlayerOptions? playerOptions, bool showPictureInPicture = true, ValueChanged<bool> ? onControlsPinnedChanged, VoidCallback? onPictureInPicture, VoidCallback? onFullscreenToggle, VoidCallback? onPlaybackRequested, VoidCallback? onPlaybackPaused, ValueListenable<bool> ? liveSegmentWaitingListenable}) -
const
Properties
-
availableQualities
→ List<
VideoQualityOption> -
final
- controlsController → VideoControlsController
-
final
- currentQuality → VideoQualityOption?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
liveSegmentWaitingListenable
→ ValueListenable<
bool> ? -
final
-
onControlsPinnedChanged
→ ValueChanged<
bool> ? -
final
- onControlsVisibilityChanged → dynamic Function(bool visbility)
-
final
- onFullscreenToggle → VoidCallback?
-
final
- onPictureInPicture → VoidCallback?
-
final
- onPlaybackPaused → VoidCallback?
-
final
- onPlaybackRequested → VoidCallback?
-
final
-
onQualitySelected
→ Future<
void> Function(VideoQualityOption quality)? -
final
- player → Player
-
final
- playerOptions → ZerorateHlsPlayerOptions?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showPictureInPicture → bool
-
final
- syncVisibilityWithParent → bool
-
final
- videoControlsConfig → VideoControlsConfig
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CustomVideoControls> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited