NowPlayingConfig class
Constructors
- NowPlayingConfig({bool enabled = true, bool keepVisibleWhilePaused = true, bool keepAliveWhilePipActive = true, bool clearWhenBackgroundedWithoutPip = true, required NowPlayingMetadata metadata})
-
const
Properties
- clearWhenBackgroundedWithoutPip → bool
-
final
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- keepAliveWhilePipActive → bool
-
final
- keepVisibleWhilePaused → bool
-
final
- metadata → NowPlayingMetadata
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited