models/video_controls_config library
Classes
- SeekPreviewPerformanceOptions
- Performance options for the seek preview to optimize for different devices.
- SubtitleSource
- Subtitle source definition
- VideoControlsConfig
- Configuration class for video controls.
- VideoControlsController
- Internal controller used by the SDK to coordinate default video controls.
- VideoControlsData
- Additional state passed to custom video controls and overlay builders.
- VideoQualityOption
- VideoResolution
- Resolution definition
Enums
Typedefs
- VideoCustomControlsBuilder = Widget Function(BuildContext context, VideoControlsData data)
- Builder for fully custom video controls.
- VideoOverlayBuilder = Widget Function(BuildContext context, VideoControlsData data)
- Builder for additional video UI layered on top of the player surface.